﻿-- Addon declaration
MalygosFlamer = LibStub("AceAddon-3.0"):NewAddon("MalygosFlamer", "AceEvent-3.0", "AceTimer-3.0")

-- Our options table
local mflamer_options

-- Localization table
local L = {
	["enter"] = "You have entered the Eye of Eternity. MalygosFlamer has been enabled.",
	["leave"] = "You have left the Eye of Eternity. MalygosFlamer has been disabled.",
	["failbuff"] = "Debuff expired",
	["failaura"] = "Melee Range Aura",
	["manualenable"] = "MalygosFlamer has been enabled manually.",
	["manualdisable"] = "MalygosFlamer has been disabled manually.",
	["broadcast_self"] = "Fails are now broadcasted locally",
	["broadcast_guild"] = "Fails are now broadcasted to your guild",
	["broadcast_party"] = "Fails are now broadcasted to your party",
	["broadcast_raid"] = "Fails are now broadcasted to your raid",
	["zonename"] = "The Eye of Eternity",
	["malygos"] = "Malygos",
	["falseinput1"] = "You have either specified no or an incorrect setting.",
	["falseinput2"] = "Settings aviable:",
	["falseinput3"] = "SELF --> Lokale Meldung",
	["falseinput4"] = "GROUP --> Broadcast to your party",
	["falseinput5"] = "RAID --> Broadcast to your raid",
	["falseinput6"] = "GUILD --> Broadcast to your guild",
}
if GetLocale() == "deDE" then
	L = {
		["enter"] = "Ihr habt das Auge der Ewigkeit betreten. MalygosFlamer wurde aktiviert.",
		["leave"] = "Ihr habt das Auge der Ewigkeit verlassen. MalygosFlamer wurde deaktiviert.",
		["failbuff"] = "Debuff abgefallen",
		["failaura"] = "Meleerange",
		["manualenable"] = "MalygosFlamer wurde manuell aktiviert.",
		["manualdisable"] = "MalygosFlamer wurde manuell deaktiviert.",
		["broadcast_self"] = "Fails werden nun dir lokal gemeldet",
		["broadcast_guild"] = "Fails werden nun deiner Gilde bekanntgegeben",
		["broadcast_party"] = "Fails werden nun deiner Gruppe bekanntgegeben",
		["broadcast_raid"] = "Fails werden nun deinem Schlachtzug bekanntgegeben",
		["zonename"] = "Das Auge der Ewigkeit",
		["malygos"] = "Malygos",
		["falseinput1"] = "Keine oder eine inkorrekte Einstellung angegeben.",
		["falseinput2"] = "Folgende Einstellungen existieren:",
		["falseinput3"] = "SELF --> Lokale Meldung",
		["falseinput4"] = "GROUP --> Meldung an deine Gruppe",
		["falseinput5"] = "RAID --> Meldung an deinen Schlachtzug",
		["falseinput6"] = "GUILD --> Meldung an deine Gilde",
	}
end

-- Assign the right table based on locale
if GetLocale() == "deDE" then
    mflamer_options = {
        name = "MalygosFlamer",
        handler = MalygosFlamer,
        type = 'group',
        args = {
            msg = {
                type = 'input',
                name = 'Broadcast',
                desc = 'Setze den Channel, an den Fails gesandt werden. RAID = Schlachtzug, GROUP = Gruppe, GUILD = Gilde, SELF = Lokal',
                set = 'SetSendChannel',
                get = 'GetSendChannel',
            },
			manual = {
				type = 'input',
				name = 'Manually',
				desc = 'Steuere viele Aspekte des Addons manuell: ENABLE --> Aktiviert das Addon manuell',
				set = 'DoManualInput',
				get = 'ManualInputGetDummy',
			},
        },
    }
    DEFAULT_CHAT_FRAME:AddMessage("MalygosFlamer erfolgreich geladen.");
else
    mflamer_options = {
        name = "MalygosFlamer",
        handler = MalygosFlamer,
        type = 'group',
        args = {
            msg = {
                type = 'input',
                name = 'Broadcast',
                desc = 'Set the Channel to which the Fails should be broadcasted. RAID = Raid, GROUP = Party, GUILD = Guild, SELF = Local',
                set = 'SetSendChannel',
                get = 'GetSendChannel',
            },
			manual = {
				type = 'input',
				name = 'Manually',
				desc = 'Control the addon manually. ENABLE toggles the addon manually.',
				set = 'DoManualInput',
				get = 'ManualInputGetDummy',
			},
        },
    }
    DEFAULT_CHAT_FRAME:AddMessage("MalygosFlamer loaded successfully!");
end


-- Declare local functions first, so that later functions defined below them can use them.
local function IsEyeOfEternity(self)
    if GetRealZoneText() == L["zonename"] then
		DEFAULT_CHAT_FRAME:AddMessage(L["enter"]);
		mflamer_enabled=1;
        MalygosFlamer:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
	elseif mflamer_enabled == 1 then
		if not mflamer_manual == 1 then
			MalygosFlamer:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
			DEFAULT_CHAT_FRAME:AddMessage(L["leave"]);
		end
	end
end

local function GetUnitIdFromName(name)
    if name == UnitName("target") then
        return "target"
    end
    for i = 1, GetNumRaidMembers() do
        local raidTarget = format("%s%d%s", "raid", i, "target")
        if name == UnitName(raidTarget) then
            return raidTarget
        end
    end
end

local function GetRaidMemberPet(guid)
    if (UnitGUID("pet") == guid) then
        return UnitName("player")
    else
        for c = 1, GetNumRaidMembers() do
            local pet = format("%s%d", "raidpet", c);
            if (UnitGUID(pet) == guid) then
                local member = format("%s%d", "raid", c);
                return UnitName(member)
            end
        end
    end
end

local function GetRaidMemberAlive(guid)
    if (UnitGUID("pet") == guid) then
        if UnitHealth("pet") > 0 then
            return true;
        else
            return false;
        end
    else
        for c = 1, GetNumRaidMembers() do
            local pet = format("%s%d", "raidpet", c);
            if (UnitGUID(pet) == guid) then
                if UnitHealth(pet) > 0 then
                    return true;
                else
                    return false;
                end
            end
        end
    end
end


-- Called on "ADDON_LOADED" event with arg1 == "MalygosFlamer" by AceAddon-3.0
function MalygosFlamer:OnInitialize()
    LibStub("AceConfig-3.0"):RegisterOptionsTable("MalygosFlamer", mflamer_options, {"malygosflamer", "mflamer"});
end

-- Called on "PLAYER_LOGIN" event by AceAddon-3.0
function MalygosFlamer:OnEnable()
    self:RegisterEvent("PLAYER_ENTERING_WORLD")
end

function MalygosFlamer:PLAYER_ENTERING_WORLD()
	MalygosFlamer:ScheduleTimer(IsEyeOfEternity, 1, self);
end

function MalygosFlamer:COMBAT_LOG_EVENT_UNFILTERED(event, ...)
    local timestamp, type, sourceGUID, sourceName, sourceFlags, destGUID, destName, destFlags, spellId, spellName, spellType = ...
    if type == "SPELL_AURA_REMOVED" then
       -- if destName=="Malygos" then  -- Note you need to localize the name "Malygos", or extract the mob ID from the GUID
            local uid = GetUnitIdFromName(destName);
            if uid then
                local health = UnitHealth(uid);
                if health > 50000 then
                    if ((spellId == 56092) or (spellId == 61621)) then
                        local hashefailed = GetRaidMemberAlive(sourceGUID);
                        if hashefailed then
                            local failor = GetRaidMemberPet(sourceGUID);
							if mflamer_channel == "SELF" then
								DEFAULT_CHAT_FRAME:AddMessage(L["failbuff"]..": "..failor);
							elseif mflamer_channel == "GROUP" then
								SendChatMessage(L["failbuff"]..": "..failor, "PARTY");
							elseif mflamer_channel == "RAID" then
								SendChatMessage(L["failbuff"]..": "..failor, "RAID");
							elseif mflamer_channel == "GUILD" then
								SendChatMessage(L["failbuff"]..": "..failor, "GUILD");
							end
                        end
                    end
                end
            end
       -- end
    elseif type == "SPELL_DAMAGE" then
		if sourceName == "Malygos" and spellID == 57432 then
			local failor = GetRaidMemberPet(destGUID);
			if mflamer_channel == "SELF" then
				DEFAULT_CHAT_FRAME:AddMessage(L["failaura"]..": "..failor);
			elseif mflamer_channel == "GROUP" then
				SendChatMessage(L["failaura"]..": "..failor, "PARTY");
			elseif mflamer_channel == "RAID" then
				SendChatMessage(L["failaura"]..": "..failor, "RAID");
			elseif mflamer_channel == "GUILD" then
				SendChatMessage(L["failaura"]..": "..failor, "GUILD");
			end
		end
	end
end

function MalygosFlamer:ManualInputGetDummy(info)
	return nil
end

function MalygosFlamer:DoManualInput(info, input)
	if input == "ENABLE" or input == "enable" then
		if mflamer_enabled == 1 then
			mflamer_enabled = 0;
			mflamer_manual = 0;
			DEFAULT_CHAT_FRAME:AddMessage(L["manualdisable"]);
			MalygosFlamer:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
		else
			mflamer_enabled = 1;
			mflamer_manual = 1;
			DEFAULT_CHAT_FRAME:AddMessage(L["manualenable"]);
			MalygosFlamer:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
		end
	end
end

function MalygosFlamer:GetSendChannel(info)
    return mflamer_channel
end

function MalygosFlamer:SetSendChannel(info, input)
    if input == "SELF" or input == "self" then
        DEFAULT_CHAT_FRAME:AddMessage(L["broadcast_self"]);
        mflamer_channel = "SELF";
    elseif input == "GUILD" or input == "guild" then
        DEFAULT_CHAT_FRAME:AddMessage(L["broadcast_guild"]);
        mflamer_channel = "GUILD";
    elseif input == "GROUP" or input == "group" then
		DEFAULT_CHAT_FRAME:AddMessage(L["broadcast_party"]);
        mflamer_channel = "GROUP";
    elseif input == "RAID" or input == "raid" then
		DEFAULT_CHAT_FRAME:AddMessage(L["broadcast_raid"]);
        mflamer_channel = "RAID";
    else
    DEFAULT_CHAT_FRAME:AddMessage(L["falseinput1"]);
	DEFAULT_CHAT_FRAME:AddMessage(L["falseinput2"]);
	DEFAULT_CHAT_FRAME:AddMessage(L["falseinput3"]);
	DEFAULT_CHAT_FRAME:AddMessage(L["falseinput4"]);
	DEFAULT_CHAT_FRAME:AddMessage(L["falseinput5"]);
	DEFAULT_CHAT_FRAME:AddMessage(L["falseinput6"]);
    end
end
